@@ -29,7 +29,7 @@ async def generate(request: ImageRequest, api_key: Optional[str] = None):
     client = AsyncClient(base_url=BASE_URL, api_key=api_key)
 
     data = {
-        **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
+        **request.model_dump(exclude={"extra_fields", "aspect_ratio"}),
         **(request.extra_fields or {})
     }
 
