@@ -7,9 +7,9 @@
 # @WeChat       : meutils
 # @Software     : PyCharm
 # @Description  : 统一收口 todo 硅基
-import os
 
 from meutils.pipe import *
+from meutils.apis.utils import create_http_client
 from meutils.llm.clients import AsyncClient
 from meutils.llm.openai_utils import to_openai_params
 from meutils.io.files_utils import to_png, to_url_fal, to_url
@@ -33,15 +33,23 @@ from meutils.apis.ppio.images import generate as ppio_generate
 from meutils.apis.runware.images import generate as runware_generate
 from meutils.apis.vmodel.images import generate as vmodel_generate
 from meutils.apis.freepik.images import generate as freepik_generate
+from meutils.apis.siliconflow.images_pro import generate as siliconflow_generate
+from meutils.apis.replicate.images import generate as replicate_generate
 
 
 async def generate(
         request: ImageRequest,
         api_key: Optional[str] = None,
         base_url: Optional[str] = None,
+        http_client: Optional[Any] = None,
 ):
-    if len(str(request)) < 1024:
-        logger.debug(request)
+    if len(str(request)) < 1024: logger.debug(request)
+
+    if "siliconflow" in base_url:  # 硅基
+        return await siliconflow_generate(request, api_key, base_url)
+
+    if "replicate" in base_url:  # 硅基
+        return await replicate_generate(request, api_key, base_url)
 
     if api_key and api_key.startswith("FPS"):  # freepik
         return await freepik_generate(request, api_key)
@@ -56,7 +64,6 @@ async def generate(
         # https://fal.media/files/panda/FlN5Gk0KnHe4AXU6Jeyvo_c5795dc52214423cb6465dae8eeaa1f0.png
         # https://s3ai.cn/fal/files/panda/FlN5Gk0KnHe4AXU6Jeyvo_c5795dc52214423cb6465dae8eeaa1f0.png
 
-        #
 
         # """https://fal.media/files/b/rabbit/-Cvx3pnaB0p6p_RLXlfuo.png
         # """
@@ -120,7 +127,7 @@ async def generate(
 
     # 其他
     data = {
-        **request.model_dump(exclude_none=True, exclude={"extra_fields", "aspect_ratio"}),
+        **request.model_dump(exclude={"extra_fields", "aspect_ratio"}),
         **(request.extra_fields or {})
     }
     request = ImageRequest(**data)
@@ -173,7 +180,11 @@ async def generate(
     if len(str(data)) < 1024:
         logger.debug(bjson(data))
 
-    client = AsyncClient(api_key=api_key, base_url=base_url)
+    client = AsyncClient(
+        api_key=api_key,
+        base_url=base_url,
+        http_client=await create_http_client(http_client)
+    )
     response = await client.images.generate(**data)
     return response
 
@@ -227,10 +238,17 @@ if __name__ == '__main__':
     api_key = "FPSXc7a13cdcd4893ff3aa053749d05485a7"
     model = "gemini-2-5-flash-image-preview"
 
+    model = "nano-banana"
+    base_url = "https://api.gptnb.ai/v1"
+    api_key = "sk-xTr62I0GYAZ8c1CbDe2e0495954d4eA0B5C147Ba94AeCd67"
+
     request = ImageRequest(
         model=model,
+        size=None,
         prompt="带个墨镜",
         image=["https://s3.ffire.cc/files/jimeng.jpg"],
     )
 
+    logger.debug(request)
+
     arun(generate(request, api_key=api_key, base_url=base_url))
