@@ -9,9 +9,13 @@
 # @Description  :
 
 from meutils.pipe import *
+from meutils.str_utils.json_utils import json_path
 from meutils.hash_utils import murmurhash
 from meutils.schemas.oneapi import BASE_URL, GROUP_RATIO
 from meutils.schemas.oneapi._types import ChannelInfo
+from meutils.schemas.db.oneapi_types import OneapiChannel
+
+from meutils.db.orm import update_or_insert
 
 headers = {
     'authorization': f'Bearer {os.getenv("CHATFIRE_ONEAPI_TOKEN")}',
@@ -19,7 +23,31 @@ headers = {
     'rix-api-user': '1',
 }
 
-"https://api.ffire.cc/api/channel/multi_key/manage"
+filter_kwargs = {
+    # "key": "gpoH1z3G6nHovD8MY40i6xx5tsC1vbh7B3Aao2jmejYNoKhv",
+    # "key": "610d41b8-0b6e-4fba-8439-f5178b733f3a",
+    "id": 21249,
+}
+
+
+# async def update_channel(id: int, base_url: str):
+#     arun(update_or_insert(OneapiChannel, filter_kwargs, update_fn))
+#
+#     filter_kwargs = {
+#         "id": "1",
+#     }
+#
+#     async def update_fn(data):
+#         data.key = "k1\nk2\nk3"
+#         return data
+#
+#     async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30) as client:
+#         response = await client.get(f"/api/channel/{id}")
+#         response.raise_for_status()
+#
+#         data = response.json()
+#         logger.debug(bjson(data))
+#         return data
 
 
 async def manage_multi_key(id: int, base_url: str, action: str = "enable_all_keys") -> ChannelInfo:
@@ -27,7 +55,7 @@ async def manage_multi_key(id: int, base_url: str, action: str = "enable_all_key
     payload = {
         "channel_id": id,
         "action": action
-    }
+    }  #
     async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30) as client:
         response = await client.post("/api/channel/multi_key/manage", json=payload)
         response.raise_for_status()
@@ -37,7 +65,7 @@ async def manage_multi_key(id: int, base_url: str, action: str = "enable_all_key
         return data
 
 
-async def get_channel_info(id: int, base_url: str) -> ChannelInfo:
+async def get_channel_info(id: int, base_url: str, response_format: Optional[str] = None):
     params = {"keyword": id}  # keyword=21222&group=&model=&id_sort=true&tag_mode=false&p=1&page_size=100
 
     async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=30) as client:
@@ -46,8 +74,16 @@ async def get_channel_info(id: int, base_url: str) -> ChannelInfo:
 
         data = response.json()
         logger.debug(bjson(data))
+
         if (items := data.get("data", {}).get("items", [])) and (item := items[0]):
-            return item['status']  # status==1 是正常
+            if not response_format: return item
+
+            if response_format == "status":  # multi_key_status
+                return item.get("status") == 1  # status==1 是正常
+
+            elif item.get("status") == 1 and not item.get("channel_info", {}).get("multi_key_status_list"):
+                logger.debug(f"渠道 {id} 渠道全key正常")
+                return True
 
 
 async def edit_channel(models, token: Optional[str] = None):
@@ -133,7 +169,7 @@ async def exist_channel(
 
         if items := response.json()['data']['items']:
             _ = [item for item in items if item['id'] == request.id]
-            logger.debug(_)
+            # logger.debug(_)
 
             return _
         else:
@@ -190,8 +226,7 @@ async def create_or_update_channel(
 
     async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=100) as client:
         response = await client.request(method, "/api/channel/", json=payload)
-        logger.debug(response.text)
-
+        # logger.debug(response.text)
         response.raise_for_status()
 
         data = response.json()
@@ -270,6 +305,21 @@ async def delete_channel(id, base_url: Optional[str] = "https://api.ffire.cc"):
             logger.debug(response.json())
 
 
+async def update_channel(id: int, base_url: str, **kwargs):
+    """只更新keys"""
+
+    # key_mode: Optional[Literal['append', 'replace']] = None  # none是覆盖
+
+    if channel_info := await get_channel_info(id, base_url):
+        channel_info = {**channel_info, **kwargs}
+
+        async with httpx.AsyncClient(base_url=base_url, headers=headers, timeout=100) as client:
+            response = await client.request("PUT", "/api/channel/", json=channel_info)
+            response.raise_for_status()
+
+            return response.json()
+
+
 if __name__ == '__main__':
     from meutils.config_utils.lark_utils import get_series
 
@@ -284,7 +334,7 @@ if __name__ == '__main__':
     #
     base_url = "https://api.ffire.cc"
     # base_url = "https://usa.chatfire.cn"
-    # base_url = "https://api.chatfire.cn"
+    base_url = "https://api.chatfire.cn"
 
     # tokens = arun(get_series(FEISHU_URL))  # [:5]
     # arun(create_or_update_channel(tokens, base_url))
@@ -297,17 +347,18 @@ if __name__ == '__main__':
                           # key_mode="append"
                           )
 
+    request = ChannelInfo(id=29499, key=key, type=45)
 
-
-    request = ChannelInfo(id=29494, key=key, type=45)
-
-    arun(create_or_update_channel(request, base_url=base_url))
+    # arun(create_or_update_channel(request, base_url=base_url))
     #
     # arun(exist_channel(request, base_url=base_url))
 
     # arun(get_channel_info(21222, base_url=base_url))
-    # arun(get_channel_info(29483, base_url=base_url))
+    # arun(get_channel_info(29495, base_url=base_url, response_format="status"))
+    # arun(get_channel_info(29495, base_url=base_url, response_format="multi_key_status"))
 
     # arun(delete_channel(range(10015, 10032), base_url=base_url))
 
-    # arun(manage_multi_key(29483, base_url=base_url))
+    # arun(manage_multi_key(29499, base_url=base_url))
+
+    arun(update_channel(21249, base_url=base_url, key=key, key_mode="append"))
