@@ -18,6 +18,22 @@ cache = memory_cache = cached
 RedisCache.delete_all = lambda *args, **kwargs: caches.get(RedisCache).clear(*args, **kwargs)
 
 
+def get_cache_object():
+    connection_kwargs = {}
+    if REDIS_URL := os.getenv("REDIS_URL"):
+        user_password, base_url = REDIS_URL.split("@")
+        endpoint, port = base_url.split(':')
+        password = user_password.split(":")[-1]
+
+        connection_kwargs['endpoint'] = endpoint
+        connection_kwargs['port'] = port
+        connection_kwargs['password'] = password
+
+        cache = RedisCache(**connection_kwargs)
+
+    return cache
+
+
 def rcache(**kwargs):
     """serializer="pickle"
 
@@ -83,4 +99,3 @@ if __name__ == '__main__':
     # arun(main(fn2))
 
     arun(main(mfn))
-
