@@ -345,11 +345,13 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
 
 @retrying()
 # @rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
-async def check_token_for_fal(token, threshold: float = 0):
+async def check_token_for_fal(api_key, threshold: float = 0):
+    if not isinstance(api_key, str):
+        return await check_tokens(api_key, check_token_for_fal)
     try:
         # data = await AsyncClient(key=token).upload(b'', '', '')
         from fal_client.client import AsyncClient
-        data = await AsyncClient(key=token).run(
+        data = await AsyncClient(key=api_key).run(
             "fal-ai/any-llm/enterprise",
             arguments={
                 "model": "meta-llama/llama-3.2-1b-instruct",
@@ -357,9 +359,13 @@ async def check_token_for_fal(token, threshold: float = 0):
                 "max_tokens": 1,
             },
         )
-        # fal-ai/any-llm/enterprise
+        # fal - ai / any - llm / enterprise
         logger.debug(data)
         return True
+
+    except TimeoutException as e:
+        raise
+
     except Exception as exc:
         logger.error(exc)
         return False
@@ -453,6 +459,46 @@ async def check_token_for_runware(api_key, threshold: float = 5):
         return False
 
 
+@retrying()
+async def check_token_for_aimlapi(api_key, threshold: float = 10000):
+    base_url = "https://billing.aimlapi.com/v1"
+    if not isinstance(api_key, str):
+        return await check_tokens(api_key, check_token_for_aimlapi)
+
+    try:
+        client = AsyncOpenAI(base_url=base_url, api_key=api_key)
+        data = await client.get("/billing/balance", cast_to=object)
+        logger.debug(bjson(data))
+
+        return data['balance'] > threshold
+
+    except TimeoutException as e:
+        raise
+
+    except Exception as e:
+        logger.error(f"Error: {e}\n{api_key}")
+        return False
+
+
+@retrying()
+async def check_token_for_aimlapi(api_key, threshold: float = 10000):
+    base_url = "https://billing.aimlapi.com/v1"
+    if not isinstance(api_key, str):
+        return await check_tokens(api_key, check_token_for_aimlapi)
+
+    try:
+        client = AsyncOpenAI(base_url=base_url, api_key=api_key)
+        data = await client.get("/billing/balance", cast_to=object)
+        logger.debug(bjson(data))
+
+        return data['balance'] > threshold
+
+    except TimeoutException as e:
+        raise
+
+    except Exception as e:
+        logger.error(f"Error: {e}\n{api_key}")
+        return False
 
 
 if __name__ == '__main__':
@@ -514,6 +560,12 @@ if __name__ == '__main__':
     # # api_key = None
     # arun(check_token_for_openrouter(api_key=api_key or os.getenv("OPENROUTER_API_KEY")))
 
-    api_key = "P8nkXmMKfoPlSR3iR48Jbl4vs8aLP1TT"
+    # api_key = "P8nkXmMKfoPlSR3iR48Jbl4vs8aLP1TT"
 
-    arun(check_token_for_runware(api_key))
+    # arun(check_token_for_runware(api_key))
+
+    api_key = "603051fc1d7e49e19de2c67521d4a30e"
+    # api_key = "f63aeefc6db54ba1ad51166ef5e4ab5f"
+    # api_key="0b42a4a4019b4123a80b715f968fdaf6"
+
+    arun(check_token_for_aimlapi(api_key))
