@@ -108,7 +108,7 @@ class ImageRequest(BaseModel):  # openai
 
     # 测试默认值 Optional[Literal["256x256", "512x512", "1024x1024", "1792x1024", "1024x1792"]]
     n: Optional[int] = 1
-    size: Optional[str] = '1024x1024'  # null auto
+    size: Optional[str] = None  # null auto
 
     output_format: Optional[Literal["png", "jpeg", "webp"]] = None
     response_format: Optional[Literal["url", "b64_json", "oss_url", "glb", "stl"]] = "url"
@@ -134,6 +134,8 @@ class ImageRequest(BaseModel):  # openai
     image: Optional[Union[str, List[str], bytes, List[bytes]]] = None  # url b64 file_bytes
     watermark: Optional[bool] = None
 
+    resolution: Optional[str] = None  # 1k 2k 4k
+
     def __init__(self, /, **data: Any):
         super().__init__(**data)
         # 规避空字符
@@ -147,13 +149,16 @@ class ImageRequest(BaseModel):  # openai
             if self.aspect_ratio:  # 适配比例
                 self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
 
-            elif self.size == 'auto':
+            elif self.size in {None, 'auto', 'match_input_image'}:
                 self.size = self.aspect_ratio = None
 
             elif self.size:  # 适配尺寸
                 self.aspect_ratio = size2aspect_ratio(self.size)
                 self.size = self.size if 'x' in self.size else '512x512'
 
+        if not self.resolution and '_' in self.model and self.model.endswith('k'):  # _4k
+            self.model, self.resolution = self.model.rsplit('_', maxsplit=1)
+
     @cached_property
     def image_urls(self) -> List[str]:
         if self.image:
@@ -223,7 +228,7 @@ class ImageEditRequest(BaseModel):
 
     n: Optional[int] = 1
     size: Optional[
-        Union[str, Literal["256x256", "512x512", "1024x1024", "1536x1024", "1024x1536", "auto"]]] = "1024x1024"
+        Union[str, Literal["256x256", "512x512", "1024x1024", "1536x1024", "1024x1536", "auto"]]] = None
 
     aspect_ratio: Optional[str] = None
 
@@ -251,16 +256,16 @@ class ImageEditRequest(BaseModel):
             if self.aspect_ratio:  # 适配比例
                 self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')
 
-            elif self.size == 'auto':
+            elif self.size in {None, 'auto', 'match_input_image'}:
                 self.size = self.aspect_ratio = None
 
             elif self.size:  # 适配尺寸
-                # if self.size.lower().endswith('k'):
-                #     size = int(self.size.lower().split('k')[0]) * 1024
-                #     self.size = f"{size}x{size}"
                 self.aspect_ratio = size2aspect_ratio(self.size)
                 self.size = self.size if 'x' in self.size else '512x512'
 
+        if not self.resolution and '_' in self.model and self.model.endswith('k'):  # _4k
+            self.model, self.resolution = self.model.rsplit('_', maxsplit=1)
+
 
 class FalImageRequest(ImageRequest):
     prompt: str
@@ -706,7 +711,40 @@ if __name__ == '__main__':
 
     # print(dict(Image()))
 
-    print(ImageRequest(aspect_ratio="2:1"))
+    # print(ImageRequest(aspect_ratio="2:1"))
     print(ImageRequest(size="8x2", aspect_ratio="2:1"))  # aspect_ratio优先级更高
     print(ImageRequest(size="8x2"))
-    print(ImageRequest(size="8:2"))
+    print(ImageRequest(aspect_ratio="auto"))
+    print(ImageRequest(size="auto"))
+
+    print(ImageRequest(size=None))
+
+    print(ImageRequest(aspect_ratio="match_input_image"))
+    print(ImageRequest())
+
+    # print(ImageRequest(size="auto"))
+    # print(ImageRequest(size=None))
+    #
+    # print(ImageRequest(
+    #     size=None,
+    #     model="model",
+    #     prompt="带个墨镜",
+    #     image=["https://s3.ffire.cc/files/jimeng.jpg"],
+    # ))
+    #
+    #
+    # print(ImageRequest(
+    #     model="model",
+    #     size=None,
+    #     prompt="带个墨镜",
+    #     image=["https://s3.ffire.cc/files/jimeng.jpg"],
+    # ))
+
+    _ = ImageRequest(
+        model="model",
+        size=None,
+        prompt="带个墨镜",
+        image=["https://s3.ffire.cc/files/jimeng.jpg"],
+    )
+
+    # print(_)
