@@ -150,6 +150,8 @@ MODEL_PRICE = {
 
     "nano-banana": 0.04 * 3,
     "nano-banana-pro": 0.04 * 4,
+    "nano-banana-pro_4k": 0.3,
+
 
     "gemini-2.5-flash-image": 0.04 * 3,
     "gemini-2.5-flash-image-preview": 0.08,
@@ -315,6 +317,7 @@ MODEL_PRICE = {
 
     # grok
     "grok-3-image": 0.1,
+    "grok-imagine-0.9": 0.1,
 
     # 虚拟换衣fish
     "api-kolors-virtual-try-on": 0.1,
@@ -480,6 +483,8 @@ MODEL_PRICE = {
     "chat-suno": 0.6,
 
     # all
+    "grok-4.1": 0.02,
+
     "o1-plus": 0.2,
     "o1-pro": 1.2,
 
@@ -719,6 +724,8 @@ MODEL_RATIO = {
 
     "grok-4-fast-reasoning": 0.1,
     "grok-4-fast-non-reasoning": 0.1,
+    "grok-4-1-fast-reasoning": 0.1,
+    "grok-4-1-fast-non-reasoning": 0.1,
 
     # 定制
     "lingxi-all": 1,
@@ -915,17 +922,9 @@ MODEL_RATIO = {
     "yi-medium-200k": 6,
 
     # minimax https://platform.minimaxi.com/document/price?id=6433f32294878d408fc8293e
-    "minimax-text-01": 0.5,
     "minimax-m1-80k": 2,
     "minimax-m2": 1,
 
-    "abab6.5-chat": 15 / 7.5,
-    "abab6.5s-chat": 5,
-    "abab6.5t-chat": 2.5,
-    "abab6.5g-chat": 2.5,
-    "abab5.5-chat": 7.5,
-    "abab5.5s-chat": 2.5,
-
     # deepseek
     "deepseek-prover-v2-671b": 2,
     "deepseek-v3": 1,
@@ -939,11 +938,14 @@ MODEL_RATIO = {
     "deepseek-v3.1": 2,
     "deepseek-v3-1-250821": 2,
     "deepseek-v3-1-think": 2,
+    "deepseek-v3-1-thinking": 2,
 
     "deepseek-v3-1-terminus": 2,
     "deepseek-v3.1-terminus": 2,
-    "deepseek-v3.2-exp": 1,
-    "deepseek-v3-2-exp": 1,
+    "deepseek-v3.2-exp": 1.5,
+    "deepseek-v3-2-exp": 1.5,
+    "deepseek-v3.2-thinking": 1.5,
+    "deepseek-v3.2-exp-thinking": 1.5,
 
     "deepseek-chat-8k": 0.5,
     "deepseek-chat-64k": 5,
@@ -1002,6 +1004,7 @@ MODEL_RATIO = {
     "doubao-seed-1-6-thinking-250615": 0.4,
     "doubao-seed-1-6-thinking-250715": 0.4,
     "doubao-seed-1-6-vision-250815": 0.4,
+    "doubao-seed-code-preview-251028": 0.6,
 
     "doubao-1-5-ui-tars-250428": 1.75,
     "ui-tars-72b": 1.75,
@@ -1220,7 +1223,9 @@ MODEL_RATIO = {
     "gemini-2.5-pro-exp-03-25-thinking": 0.625,
     "gemini-2.5-pro-preview-03-25-thinking": 0.625,
 
-    "gemini-thinking": 0.625,  # 逆向
+    "gemini-3-pro": 1,
+    "gemini-3-pro-preview": 1,
+    "gemini-3-pro-thinking": 1,
 
     "gpt-3.5-turbo": 0.75,
     "gpt-3.5-turbo-0125": 0.25,
@@ -1271,10 +1276,11 @@ MODEL_RATIO = {
 
     "gpt-5": 0.625,
     "gpt-5.1": 0.625,
+    "gpt-5.1-2025-11-13": 0.625,
+    "gpt-5.1-chat-latest": 0.625,
 
     "gpt-5-2025-08-07": 0.625,
     "gpt-5-chat-latest": 0.625,
-    "gpt-5.1-chat-latest": 0.625,
 
     "gpt-5-mini": 0.125,
     "gpt-5-mini-2025-08-07": 0.125,
@@ -1420,8 +1426,11 @@ COMPLETION_RATIO = {
     "grok-3-mini-beta": 5 / 3,
     "grok-3-mini-fast-beta": 4 / 0.6,
     "grok-4": 5,
+
     "grok-4-fast-reasoning": 2.5,
     "grok-4-fast-non-reasoning": 2.5,
+    "grok-4-1-fast-reasoning": 2.5,
+    "grok-4-1-fast-non-reasoning": 2.5,
 
     "grok-code-fast-1": 7.5,
 
@@ -1472,6 +1481,7 @@ COMPLETION_RATIO = {
     "gpt-5.1-chat-latest": 8,
     "gpt-5.1-codex": 8,
     "gpt-5.1-codex-mini": 8,
+    "gpt-5.1-2025-11-13": 8,
 
     # claude
     "claude-3-5-haiku-20241022": 5,
@@ -1595,6 +1605,9 @@ COMPLETION_RATIO = {
     "gemini-2.5-flash-preview-05-20": 8.4,
     "gemini-2.5-flash-preview-05-20-nothinking": 8.4,
     "gemini-2.5-flash-preview-09-2025": 8.4,
+    "gemini-3-pro": 6,
+    "gemini-3-pro-preview": 6,
+    "gemini-3-pro-thinking": 6,
 
     "hunyuan-a52b-instruct": 5,
     "qwen2.5-coder-32b-instruct": 3,
@@ -1690,6 +1703,7 @@ COMPLETION_RATIO = {
     "doubao-seed-1-6-thinking-250615": 10,
     "doubao-seed-1-6-thinking-250715": 10,
     "doubao-seed-1-6-vision-250815": 10,
+    "doubao-seed-code-preview-251028": 6.7,
 
     "doubao-1-5-ui-tars-250428": 3.43,
     "ui-tars-72b": 4,
@@ -1769,13 +1783,17 @@ COMPLETION_RATIO = {
     "deepseek-v3-fast": 4,
     "deepseek-v3.1": 3,
     "deepseek-v3-1-250821": 3,
-    "deepseek-v3-1-think": 3,
 
     "deepseek-v3-1-terminus": 1.5,
     "deepseek-v3.1-terminus": 1.5,
     "deepseek-v3.2-exp": 1.5,
     "deepseek-v3-2-exp": 1.5,
 
+    "deepseek-v3-1-think": 3,
+    "deepseek-v3-1-thinking": 3,
+    "deepseek-v3.2-thinking": 1.5,
+    "deepseek-v3.2-exp-thinking": 1.5,
+
     'deepseek-r1': 4,
     "deepseek-r1-160k": 5,
 
