@@ -147,7 +147,7 @@ class SoraVideoRequest(BaseModel):
             self.ratio = size2aspect_ratio(self.size)
 
         if not self.resolution and '_' in self.model and self.model.endswith('p'):  # _480p
-            self.model, self.resolution = self.model.split('_', maxsplit=1)
+            self.model, self.resolution = self.model.rsplit('_', maxsplit=1)
 
     class Config:
         extra = "allow"
