@@ -10,10 +10,11 @@
 
 from meutils.pipe import *
 
+from starlette.datastructures import UploadFile
 from starlette.requests import Request, FormData
 from fastapi.security import HTTPBearer, HTTPAuthorizationCredentials
 
-from fastapi import APIRouter, File, UploadFile, Query, Form, BackgroundTasks, Depends, HTTPException as _HTTPException, \
+from fastapi import APIRouter, File, Query, Form, BackgroundTasks, Depends, HTTPException as _HTTPException, \
     Request, status
 
 
@@ -108,13 +109,21 @@ def check_api_key(auth: HTTPAuthorizationCredentials):
 #
 #     return data
 
-def form_to_dict(formdata: FormData) -> Dict[str, Union[str, List[str]]]:
+def form_to_dict(formdata: FormData, file2json: bool = False) -> Dict[str, Union[str, List[str]]]:
     """
     把表单转换成 dict；出现同名 key 时自动变成 list。
     """
     # request.form() 返回的是 FormData，它本质是个 immutable-multidict
     result: Dict[str, Union[str, List[str]]] = {}
     for key, value in formdata.multi_items():  # multi_items 会保留所有值
+        if file2json and isinstance(value, UploadFile):
+            _value = value.__dict__.copy()
+            _value.pop('file', None)
+            _value.pop('headers', None)
+            logger.debug(_value)
+            result[key] = _value
+            continue
+
         if key in result:  # 出现重复 key → 转 list
             if isinstance(result[key], list):
                 result[key].append(value)
